``pygcam.config``
=============================

See the :doc:`configuration system <config>` page for a detailed
description of available configuration variables. This page documents
the API to the configuration system.

API
---

.. automodule:: pygcam.config
   :members:
